==> hs-wx-0.13.2.1.tbz: lib/ghc-7.0.4/cabal/wx-0.13.2.1/register.sh <==
#!/bin/sh
echo 'name: wx
version: 0.13.2.1
id: wx-0.13.2.1-82eb7411fc2dfffa0d236df2a83071b6

license: OtherLicense
copyright:
maintainer: wxhaskell-devel@lists.sourceforge.net
stability:
homepage: http://haskell.org/haskellwiki/WxHaskell
package-url:
description: wxHaskell is a portable and native GUI library for Haskell.
             It is built on top of wxWidgets - a comprehensive C++
             library that is portable across all major GUI platforms;
             including GTK, Windows, X11, and MacOS X.  This version
             works with wxWidgets 2.8 and 2.9.
category: GUI, User interfaces
author: Daan Leijen
exposed: True
exposed-modules: Graphics.UI.WX.Draw Graphics.UI.WX.Media
                 Graphics.UI.WX.TopLevelWindow Graphics.UI.WX.Attributes
                 Graphics.UI.WX.Window Graphics.UI.WX.Variable Graphics.UI.WX.Events
                 Graphics.UI.WX.Frame Graphics.UI.WX.Layout Graphics.UI.WX.Controls
                 Graphics.UI.WX.Types Graphics.UI.WX.Dialogs Graphics.UI.WX.Classes
                 Graphics.UI.WX.Timer Graphics.UI.WX.Menu Graphics.UI.WX
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/wx-0.13.2.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/wx-0.13.2.1
              /usr/local/lib
hs-libraries: HSwx-0.13.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         stm-2.2.0.1-12cd6527c3703cc8ecc6713c7960412e
         wxcore-0.13.2.1-43df0c99dfec5a9cefaf346ca5c7de91
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/wx-0.13.2.1/html/wx.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/wx-0.13.2.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-wx-0.90.0.1_1.tbz: lib/ghc-7.4.1/cabal/wx-0.90.0.1/register.sh <==
#!/bin/sh
echo 'name: wx
version: 0.90.0.1
id: wx-0.90.0.1-3dad4ad7d087ad557b03fc3627f64e72

license: OtherLicense
copyright:
maintainer: wxhaskell-devel@lists.sourceforge.net
stability:
homepage: http://haskell.org/haskellwiki/WxHaskell
package-url:
synopsis: wxHaskell
description: wxHaskell is a portable and native GUI library for Haskell.
             It is built on top of wxWidgets - a comprehensive C++
             library that is portable across all major GUI platforms;
             including GTK, Windows, X11, and MacOS X.  This version
             works with wxWidgets 2.9 only.
category: GUI, User interfaces
author: Daan Leijen
exposed: True
exposed-modules: Graphics.UI.WX.Draw Graphics.UI.WX.Media
                 Graphics.UI.WX.TopLevelWindow Graphics.UI.WX.Attributes
                 Graphics.UI.WX.Window Graphics.UI.WX.Variable Graphics.UI.WX.Events
                 Graphics.UI.WX.Frame Graphics.UI.WX.Layout Graphics.UI.WX.Controls
                 Graphics.UI.WX.Types Graphics.UI.WX.Dialogs Graphics.UI.WX.Classes
                 Graphics.UI.WX.Timer Graphics.UI.WX.Menu Graphics.UI.WX
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/wx-0.90.0.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/wx-0.90.0.1
              /usr/local/lib
hs-libraries: HSwx-0.90.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         stm-2.3-2735f77d3e207163ae60f86094d82cd7
         wxcore-0.90.0.3-74dfbeb9dd9ac4282eb0b02c45f8e77b
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/wx-0.90.0.1/html/wx.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/wx-0.90.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
